@@ -1,13 +1,15 @@
 """Ptrack Template Tag"""
+import logging
+
 from django import template
-try:
-    from django.urls import reverse
-except ImportError:
-    from django.core.urlresolvers import reverse
 from django.conf import settings
-from .. import ptrack_encoder
+from django.core.exceptions import ImproperlyConfigured
+from django.urls import reverse
 from django.utils.html import mark_safe
 
+from ptrack import ptrack_encoder
+
+logger = logging.getLogger(__name__)
 register = template.Library()
 
 
@@ -20,6 +22,7 @@ def ptrack(*args, **kwargs):
 
         url = "%s%s" % (settings.PTRACK_APP_URL, sub_path)
     else:
-        raise Exception("PTRACK_APP_URL not defined")
+        raise ImproperlyConfigured("PTRACK_APP_URL not defined")
 
+    logger.debug("Ptrack tag generated URL: {}".format(url))
     return mark_safe("<img src='%s' width=1 height=1>" % (url,))
